flutter_cockpit_protocol

Pure Dart protocol models shared by flutter_cockpit and cockpit.

Most users should depend on flutter_cockpit in Flutter apps and cockpit for host tooling. This package exists so the host CLI/MCP package can run from pub.dev global activation without depending on the Flutter SDK.